Structs
- A collection of entities.
- An entity.
- A storage type based on a HashMap, intended for sparsely used components.
- Error indicating that an entity passed to some operation doesn’t exist. This usually indicates that the generational index of the entity was outdated.
- A storage type that stores components in a contiguous Vec
.
Traits
- Type that can be registered. Can be used to set components in ECS Worlds generated by
genesis.
Attribute Macros
- Generates an ECS (World) and a component enum containing all components.